--maximum-line-length=120
--indent-columns=4
--continuation-indentation=4
--output-line-ending=unix
--paren-tightness=2
--square-bracket-tightness=1
--brace-tightness=1
--block-brace-tightness=0
--tight-secret-operators
--noadd-semicolons
--nooutdent-long-lines
--nooutdent-long-comments
--nooutdent-long-quotes
--ignore-side-comment-lengths
--maximum-fields-per-table=4
--comma-arrow-breakpoints=2
--nospace-for-semicolon
--cuddled-else
--opening-brace-always-on-right
--stack-all-containers
--closing-token-indentation=0
--static-block-comment-prefix=#
--want-right-space=!
--notrim-qw
--noindent-closing-brace
--nodelete-old-newlines
--break-before-all-operators
--opening-token-right
--want-break-before=||
--no-outdent-labels
--freeze-blank-lines
--freeze-whitespace
